#!/usr/bin/env python

"""Script that makes the imports in the generated compiled_proto python files relative.

"""
import os
import re
import sys
import glob

PYTHON_SCRIPT_PATH = sys.argv[1]

if os.path.isdir(PYTHON_SCRIPT_PATH):
    pattern = re.compile(r"^import \w+ as \w+_pb2")
    for filepath in glob.glob(os.path.join(PYTHON_SCRIPT_PATH, "*_pb2*.py")):
        filedata = []
        with open(filepath) as f:
            for line in f.readlines():
                match = pattern.match(line)
                if match is not None:
                    line = f"from . {line}"
                filedata.append(line.strip("\n"))
        with open(filepath, "w") as f:
            f.write("\n".join(filedata))
else:
    print("Argument is not a directory")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: report.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import host_pb2 as host__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0creport.proto\x12\x06report\x1a\nhost.proto\"U\n\nBootReport\x12 \n\x04host\x18\x01 \x01(\x0b\x32\x12.report.RenderHost\x12%\n\tcore_info\x18\x02 \x01(\x0b\x32\x12.report.CoreDetail\"\xea\x01\n\nCoreDetail\x12\x13\n\x0btotal_cores\x18\x01 \x01(\x05\x12\x12\n\nidle_cores\x18\x02 \x01(\x05\x12\x14\n\x0clocked_cores\x18\x03 \x01(\x05\x12\x14\n\x0c\x62ooked_cores\x18\x04 \x01(\x05\x12\x41\n\x0ereserved_cores\x18\x05 \x03(\x0b\x32%.report.CoreDetail.ReservedCoresEntryB\x02\x18\x01\x1a\x44\n\x12ReservedCoresEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.report.CoreId:\x02\x38\x01\"\x18\n\x06\x43oreId\x12\x0e\n\x06\x63oreid\x18\x01 \x03(\x03\"\x9c\x01\n\x13\x46rameCompleteReport\x12 \n\x04host\x18\x01 \x01(\x0b\x32\x12.report.RenderHost\x12\'\n\x05\x66rame\x18\x02 \x01(\x0b\x32\x18.report.RunningFrameInfo\x12\x13\n\x0b\x65xit_status\x18\x03 \x01(\x05\x12\x13\n\x0b\x65xit_signal\x18\x04 \x01(\x05\x12\x10\n\x08run_time\x18\x05 \x01(\x05\"\x7f\n\nHostReport\x12 \n\x04host\x18\x01 \x01(\x0b\x32\x12.report.RenderHost\x12(\n\x06\x66rames\x18\x02 \x03(\x0b\x32\x18.report.RunningFrameInfo\x12%\n\tcore_info\x18\x03 \x01(\x0b\x32\x12.report.CoreDetail\"\xf2\x03\n\nRenderHost\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rnimby_enabled\x18\x02 \x01(\x08\x12\x14\n\x0cnimby_locked\x18\x03 \x01(\x08\x12\x10\n\x08\x66\x61\x63ility\x18\x04 \x01(\t\x12\x11\n\tnum_procs\x18\x05 \x01(\x05\x12\x16\n\x0e\x63ores_per_proc\x18\x06 \x01(\x05\x12\x12\n\ntotal_swap\x18\x07 \x01(\x03\x12\x11\n\ttotal_mem\x18\x08 \x01(\x03\x12\x11\n\ttotal_mcp\x18\t \x01(\x03\x12\x11\n\tfree_swap\x18\n \x01(\x03\x12\x10\n\x08\x66ree_mem\x18\x0b \x01(\x03\x12\x10\n\x08\x66ree_mcp\x18\x0c \x01(\x03\x12\x0c\n\x04load\x18\r \x01(\x05\x12\x11\n\tboot_time\x18\x0e \x01(\x05\x12\x0c\n\x04tags\x18\x0f \x03(\t\x12\"\n\x05state\x18\x10 \x01(\x0e\x32\x13.host.HardwareState\x12\x36\n\nattributes\x18\x11 \x03(\x0b\x32\".report.RenderHost.AttributesEntry\x12\x10\n\x08num_gpus\x18\x12 \x01(\x05\x12\x14\n\x0c\x66ree_gpu_mem\x18\x13 \x01(\x03\x12\x15\n\rtotal_gpu_mem\x18\x14 \x01(\x03\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfa\x03\n\x10RunningFrameInfo\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12\x10\n\x08job_name\x18\x03 \x01(\t\x12\x10\n\x08\x66rame_id\x18\x04 \x01(\t\x12\x12\n\nframe_name\x18\x05 \x01(\t\x12\x10\n\x08layer_id\x18\x06 \x01(\t\x12\x11\n\tnum_cores\x18\x07 \x01(\x05\x12\x12\n\nstart_time\x18\x08 \x01(\x03\x12\x0f\n\x07max_rss\x18\t \x01(\x03\x12\x0b\n\x03rss\x18\n \x01(\x03\x12\x11\n\tmax_vsize\x18\x0b \x01(\x03\x12\r\n\x05vsize\x18\x0c \x01(\x03\x12<\n\nattributes\x18\r \x03(\x0b\x32(.report.RunningFrameInfo.AttributesEntry\x12\x10\n\x08llu_time\x18\x0e \x01(\x03\x12\x10\n\x08num_gpus\x18\x0f \x01(\x05\x12\x1b\n\x13max_used_gpu_memory\x18\x10 \x01(\x03\x12\x17\n\x0fused_gpu_memory\x18\x11 \x01(\x03\x12+\n\x08\x63hildren\x18\x12 \x01(\x0b\x32\x19.report.ChildrenProcStats\x12\x18\n\x10used_swap_memory\x18\x13 \x01(\x03\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"8\n\x11\x43hildrenProcStats\x12#\n\x08\x63hildren\x18\x02 \x03(\x0b\x32\x11.report.ProcStats\"\x8a\x01\n\tProcStats\x12\x1a\n\x04stat\x18\x01 \x01(\x0b\x32\x0c.report.Stat\x12\x1c\n\x05statm\x18\x02 \x01(\x0b\x32\r.report.Statm\x12\x1e\n\x06status\x18\x03 \x01(\x0b\x32\x0e.report.Status\x12\x0f\n\x07\x63mdline\x18\x04 \x01(\t\x12\x12\n\nstart_time\x18\x05 \x01(\t\"L\n\x04Stat\x12\x0b\n\x03rss\x18\x01 \x01(\x03\x12\r\n\x05vsize\x18\x02 \x01(\x03\x12\r\n\x05state\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0b\n\x03pid\x18\x05 \x01(\t\"\"\n\x05Statm\x12\x0b\n\x03rss\x18\x01 \x01(\x03\x12\x0c\n\x04size\x18\x02 \x01(\x03\"%\n\x06Status\x12\x0c\n\x04vrss\x18\x01 \x01(\x03\x12\r\n\x05vsize\x18\x02 \x01(\x03\"Q\n\x18\x43hildrenProcStatsRequest\x12\x10\n\x08\x66rame_id\x18\x01 \x01(\t\x12#\n\x08\x63hildren\x18\x02 \x03(\x0b\x32\x11.report.ProcStats\"T\n\x19\x43hildrenProcStatsResponse\x12\x37\n\x14\x63hildren_procs_stats\x18\x01 \x01(\x0b\x32\x19.report.ChildrenProcStats\"o\n\x10ProcStatsRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04stat\x18\x02 \x01(\t\x12\r\n\x05statm\x18\x03 \x01(\t\x12\x0f\n\x07\x63mdline\x18\x04 \x01(\t\x12\r\n\x05state\x18\x05 \x01(\t\x12\x10\n\x08\x66rame_id\x18\x06 \x01(\t\":\n\x11ProcStatsResponse\x12%\n\nproc_stats\x18\x01 \x01(\x0b\x32\x11.report.ProcStats\"E\n\x1aRqdReportRqdStartupRequest\x12\'\n\x0b\x62oot_report\x18\x01 \x01(\x0b\x32\x12.report.BootReport\"\x1d\n\x1bRqdReportRqdStartupResponse\"d\n&RqdReportRunningFrameCompletionRequest\x12:\n\x15\x66rame_complete_report\x18\x01 \x01(\x0b\x32\x1b.report.FrameCompleteReport\")\n\'RqdReportRunningFrameCompletionResponse\"A\n\x16RqdReportStatusRequest\x12\'\n\x0bhost_report\x18\x01 \x01(\x0b\x32\x12.report.HostReport\"\x19\n\x17RqdReportStatusResponse2\xc3\x02\n\x12RqdReportInterface\x12[\n\x10ReportRqdStartup\x12\".report.RqdReportRqdStartupRequest\x1a#.report.RqdReportRqdStartupResponse\x12\x7f\n\x1cReportRunningFrameCompletion\x12..report.RqdReportRunningFrameCompletionRequest\x1a/.report.RqdReportRunningFrameCompletionResponse\x12O\n\x0cReportStatus\x12\x1e.report.RqdReportStatusRequest\x1a\x1f.report.RqdReportStatusResponseB<\n com.imageworks.spcue.grpc.reportP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'report_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.imageworks.spcue.grpc.reportP\001Z\026opencue_gateway/gen/go'
  _globals['_COREDETAIL_RESERVEDCORESENTRY']._options = None
  _globals['_COREDETAIL_RESERVEDCORESENTRY']._serialized_options = b'8\001'
  _globals['_COREDETAIL'].fields_by_name['reserved_cores']._options = None
  _globals['_COREDETAIL'].fields_by_name['reserved_cores']._serialized_options = b'\030\001'
  _globals['_RENDERHOST_ATTRIBUTESENTRY']._options = None
  _globals['_RENDERHOST_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_RUNNINGFRAMEINFO_ATTRIBUTESENTRY']._options = None
  _globals['_RUNNINGFRAMEINFO_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_BOOTREPORT']._serialized_start=36
  _globals['_BOOTREPORT']._serialized_end=121
  _globals['_COREDETAIL']._serialized_start=124
  _globals['_COREDETAIL']._serialized_end=358
  _globals['_COREDETAIL_RESERVEDCORESENTRY']._serialized_start=290
  _globals['_COREDETAIL_RESERVEDCORESENTRY']._serialized_end=358
  _globals['_COREID']._serialized_start=360
  _globals['_COREID']._serialized_end=384
  _globals['_FRAMECOMPLETEREPORT']._serialized_start=387
  _globals['_FRAMECOMPLETEREPORT']._serialized_end=543
  _globals['_HOSTREPORT']._serialized_start=545
  _globals['_HOSTREPORT']._serialized_end=672
  _globals['_RENDERHOST']._serialized_start=675
  _globals['_RENDERHOST']._serialized_end=1173
  _globals['_RENDERHOST_ATTRIBUTESENTRY']._serialized_start=1124
  _globals['_RENDERHOST_ATTRIBUTESENTRY']._serialized_end=1173
  _globals['_RUNNINGFRAMEINFO']._serialized_start=1176
  _globals['_RUNNINGFRAMEINFO']._serialized_end=1682
  _globals['_RUNNINGFRAMEINFO_ATTRIBUTESENTRY']._serialized_start=1124
  _globals['_RUNNINGFRAMEINFO_ATTRIBUTESENTRY']._serialized_end=1173
  _globals['_CHILDRENPROCSTATS']._serialized_start=1684
  _globals['_CHILDRENPROCSTATS']._serialized_end=1740
  _globals['_PROCSTATS']._serialized_start=1743
  _globals['_PROCSTATS']._serialized_end=1881
  _globals['_STAT']._serialized_start=1883
  _globals['_STAT']._serialized_end=1959
  _globals['_STATM']._serialized_start=1961
  _globals['_STATM']._serialized_end=1995
  _globals['_STATUS']._serialized_start=1997
  _globals['_STATUS']._serialized_end=2034
  _globals['_CHILDRENPROCSTATSREQUEST']._serialized_start=2036
  _globals['_CHILDRENPROCSTATSREQUEST']._serialized_end=2117
  _globals['_CHILDRENPROCSTATSRESPONSE']._serialized_start=2119
  _globals['_CHILDRENPROCSTATSRESPONSE']._serialized_end=2203
  _globals['_PROCSTATSREQUEST']._serialized_start=2205
  _globals['_PROCSTATSREQUEST']._serialized_end=2316
  _globals['_PROCSTATSRESPONSE']._serialized_start=2318
  _globals['_PROCSTATSRESPONSE']._serialized_end=2376
  _globals['_RQDREPORTRQDSTARTUPREQUEST']._serialized_start=2378
  _globals['_RQDREPORTRQDSTARTUPREQUEST']._serialized_end=2447
  _globals['_RQDREPORTRQDSTARTUPRESPONSE']._serialized_start=2449
  _globals['_RQDREPORTRQDSTARTUPRESPONSE']._serialized_end=2478
  _globals['_RQDREPORTRUNNINGFRAMECOMPLETIONREQUEST']._serialized_start=2480
  _globals['_RQDREPORTRUNNINGFRAMECOMPLETIONREQUEST']._serialized_end=2580
  _globals['_RQDREPORTRUNNINGFRAMECOMPLETIONRESPONSE']._serialized_start=2582
  _globals['_RQDREPORTRUNNINGFRAMECOMPLETIONRESPONSE']._serialized_end=2623
  _globals['_RQDREPORTSTATUSREQUEST']._serialized_start=2625
  _globals['_RQDREPORTSTATUSREQUEST']._serialized_end=2690
  _globals['_RQDREPORTSTATUSRESPONSE']._serialized_start=2692
  _globals['_RQDREPORTSTATUSRESPONSE']._serialized_end=2717
  _globals['_RQDREPORTINTERFACE']._serialized_start=2720
  _globals['_RQDREPORTINTERFACE']._serialized_end=3043
# @@protoc_insertion_point(module_scope)


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import show_pb2 as show__pb2


class ShowInterfaceStub(object):
    """Shows are the top level object for work.

    -------- Services --------]

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateFilter = channel.unary_unary(
                '/show.ShowInterface/CreateFilter',
                request_serializer=show__pb2.ShowCreateFilterRequest.SerializeToString,
                response_deserializer=show__pb2.ShowCreateFilterResponse.FromString,
                )
        self.CreateOwner = channel.unary_unary(
                '/show.ShowInterface/CreateOwner',
                request_serializer=show__pb2.ShowCreateOwnerRequest.SerializeToString,
                response_deserializer=show__pb2.ShowCreateOwnerResponse.FromString,
                )
        self.CreateServiceOverride = channel.unary_unary(
                '/show.ShowInterface/CreateServiceOverride',
                request_serializer=show__pb2.ShowCreateServiceOverrideRequest.SerializeToString,
                response_deserializer=show__pb2.ShowCreateServiceOverrideResponse.FromString,
                )
        self.CreateShow = channel.unary_unary(
                '/show.ShowInterface/CreateShow',
                request_serializer=show__pb2.ShowCreateShowRequest.SerializeToString,
                response_deserializer=show__pb2.ShowCreateShowResponse.FromString,
                )
        self.CreateSubscription = channel.unary_unary(
                '/show.ShowInterface/CreateSubscription',
                request_serializer=show__pb2.ShowCreateSubscriptionRequest.SerializeToString,
                response_deserializer=show__pb2.ShowCreateSubscriptionResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/show.ShowInterface/Delete',
                request_serializer=show__pb2.ShowDeleteRequest.SerializeToString,
                response_deserializer=show__pb2.ShowDeleteResponse.FromString,
                )
        self.EnableBooking = channel.unary_unary(
                '/show.ShowInterface/EnableBooking',
                request_serializer=show__pb2.ShowEnableBookingRequest.SerializeToString,
                response_deserializer=show__pb2.ShowEnableBookingResponse.FromString,
                )
        self.EnableDispatching = channel.unary_unary(
                '/show.ShowInterface/EnableDispatching',
                request_serializer=show__pb2.ShowEnableDispatchingRequest.SerializeToString,
                response_deserializer=show__pb2.ShowEnableDispatchingResponse.FromString,
                )
        self.FindFilter = channel.unary_unary(
                '/show.ShowInterface/FindFilter',
                request_serializer=show__pb2.ShowFindFilterRequest.SerializeToString,
                response_deserializer=show__pb2.ShowFindFilterResponse.FromString,
                )
        self.FindShow = channel.unary_unary(
                '/show.ShowInterface/FindShow',
                request_serializer=show__pb2.ShowFindShowRequest.SerializeToString,
                response_deserializer=show__pb2.ShowFindShowResponse.FromString,
                )
        self.GetActiveShows = channel.unary_unary(
                '/show.ShowInterface/GetActiveShows',
                request_serializer=show__pb2.ShowGetActiveShowsRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetActiveShowsResponse.FromString,
                )
        self.GetDeeds = channel.unary_unary(
                '/show.ShowInterface/GetDeeds',
                request_serializer=show__pb2.ShowGetDeedsRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetDeedsResponse.FromString,
                )
        self.GetDepartment = channel.unary_unary(
                '/show.ShowInterface/GetDepartment',
                request_serializer=show__pb2.ShowGetDepartmentRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetDepartmentResponse.FromString,
                )
        self.GetDepartments = channel.unary_unary(
                '/show.ShowInterface/GetDepartments',
                request_serializer=show__pb2.ShowGetDepartmentsRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetDepartmentsResponse.FromString,
                )
        self.GetFilters = channel.unary_unary(
                '/show.ShowInterface/GetFilters',
                request_serializer=show__pb2.ShowGetFiltersRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetFiltersResponse.FromString,
                )
        self.GetGroups = channel.unary_unary(
                '/show.ShowInterface/GetGroups',
                request_serializer=show__pb2.ShowGetGroupsRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetGroupsResponse.FromString,
                )
        self.GetJobs = channel.unary_unary(
                '/show.ShowInterface/GetJobs',
                request_serializer=show__pb2.ShowGetJobsRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetJobsResponse.FromString,
                )
        self.GetJobWhiteboard = channel.unary_unary(
                '/show.ShowInterface/GetJobWhiteboard',
                request_serializer=show__pb2.ShowGetJobWhiteboardRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetJobWhiteboardResponse.FromString,
                )
        self.GetRootGroup = channel.unary_unary(
                '/show.ShowInterface/GetRootGroup',
                request_serializer=show__pb2.ShowGetRootGroupRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetRootGroupResponse.FromString,
                )
        self.GetServiceOverride = channel.unary_unary(
                '/show.ShowInterface/GetServiceOverride',
                request_serializer=show__pb2.ShowGetServiceOverrideRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetServiceOverrideResponse.FromString,
                )
        self.GetServiceOverrides = channel.unary_unary(
                '/show.ShowInterface/GetServiceOverrides',
                request_serializer=show__pb2.ShowGetServiceOverridesRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetServiceOverridesResponse.FromString,
                )
        self.GetShows = channel.unary_unary(
                '/show.ShowInterface/GetShows',
                request_serializer=show__pb2.ShowGetShowsRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetShowsResponse.FromString,
                )
        self.GetSubscriptions = channel.unary_unary(
                '/show.ShowInterface/GetSubscriptions',
                request_serializer=show__pb2.ShowGetSubscriptionRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetSubscriptionResponse.FromString,
                )
        self.SetActive = channel.unary_unary(
                '/show.ShowInterface/SetActive',
                request_serializer=show__pb2.ShowSetActiveRequest.SerializeToString,
                response_deserializer=show__pb2.ShowSetActiveResponse.FromString,
                )
        self.SetCommentEmail = channel.unary_unary(
                '/show.ShowInterface/SetCommentEmail',
                request_serializer=show__pb2.ShowSetCommentEmailRequest.SerializeToString,
                response_deserializer=show__pb2.ShowSetCommentEmailResponse.FromString,
                )
        self.SetDefaultMaxCores = channel.unary_unary(
                '/show.ShowInterface/SetDefaultMaxCores',
                request_serializer=show__pb2.ShowSetDefaultMaxCoresRequest.SerializeToString,
                response_deserializer=show__pb2.ShowSetDefaultMaxCoresResponse.FromString,
                )
        self.SetDefaultMinCores = channel.unary_unary(
                '/show.ShowInterface/SetDefaultMinCores',
                request_serializer=show__pb2.ShowSetDefaultMinCoresRequest.SerializeToString,
                response_deserializer=show__pb2.ShowSetDefaultMinCoresResponse.FromString,
                )
        self.SetDefaultMaxGpus = channel.unary_unary(
                '/show.ShowInterface/SetDefaultMaxGpus',
                request_serializer=show__pb2.ShowSetDefaultMaxGpusRequest.SerializeToString,
                response_deserializer=show__pb2.ShowSetDefaultMaxGpusResponse.FromString,
                )
        self.SetDefaultMinGpus = channel.unary_unary(
                '/show.ShowInterface/SetDefaultMinGpus',
                request_serializer=show__pb2.ShowSetDefaultMinGpusRequest.SerializeToString,
                response_deserializer=show__pb2.ShowSetDefaultMinGpusResponse.FromString,
                )
        self.Archive = channel.unary_unary(
                '/show.ShowInterface/Archive',
                request_serializer=show__pb2.ShowArchiveRequest.SerializeToString,
                response_deserializer=show__pb2.ShowArchiveResponse.FromString,
                )


class ShowInterfaceServicer(object):
    """Shows are the top level object for work.

    -------- Services --------]

    """

    def CreateFilter(self, request, context):
        """Creates a new empty filter
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOwner(self, request, context):
        """Create a new owner.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateServiceOverride(self, request, context):
        """Add a new service overrides.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateShow(self, request, context):
        """Creates a show with the specified name and returns it.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSubscription(self, request, context):
        """creates a new subscription
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes a show if no jobs were ever launched for the show
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableBooking(self, request, context):
        """Enables/disables automated resource assignment. If this is disabled no new resources will be assigned but
        existing resources will continue to dispatch.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableDispatching(self, request, context):
        """Enables/disables job dispatching.  If this is disabled then new resources are assigned but existing resources
        are always unbooked after each completed frame.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindFilter(self, request, context):
        """finds a filter by name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindShow(self, request, context):
        """Find a show with the specified name.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetActiveShows(self, request, context):
        """Returns a list of all active shows.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeeds(self, request, context):
        """Return all the host deeds for the specified show.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDepartment(self, request, context):
        """Returns the department manager for the specified department
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDepartments(self, request, context):
        """Returns a list of all active departments
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFilters(self, request, context):
        """Grabs a list of show filters
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGroups(self, request, context):
        """returns a list of job groups
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetJobs(self, request, context):
        """returns a flat list of jobs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetJobWhiteboard(self, request, context):
        """returns the show's job whiteboard
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRootGroup(self, request, context):
        """returns the root group
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServiceOverride(self, request, context):
        """Get a service override based on its name or id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServiceOverrides(self, request, context):
        """Get a list of service overrides for this show.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetShows(self, request, context):
        """Returns a list of all shows
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSubscriptions(self, request, context):
        """returns a list of a shows subscriptions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetActive(self, request, context):
        """Set a show's active to enabled/disabled. Active shows can be queried using the getActiveShows() method.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetCommentEmail(self, request, context):
        """If set, all comments on a show are echoed to the given list of email addresses.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDefaultMaxCores(self, request, context):
        """sets a show's default max procs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDefaultMinCores(self, request, context):
        """sets a show's default min procs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDefaultMaxGpus(self, request, context):
        """sets a show's default max Gpus
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDefaultMinGpus(self, request, context):
        """sets a show's default min Gpus
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Archive(self, request, context):
        """Archives a show by creating an alias to another show and renaming the original show
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ShowInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateFilter': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFilter,
                    request_deserializer=show__pb2.ShowCreateFilterRequest.FromString,
                    response_serializer=show__pb2.ShowCreateFilterResponse.SerializeToString,
            ),
            'CreateOwner': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOwner,
                    request_deserializer=show__pb2.ShowCreateOwnerRequest.FromString,
                    response_serializer=show__pb2.ShowCreateOwnerResponse.SerializeToString,
            ),
            'CreateServiceOverride': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateServiceOverride,
                    request_deserializer=show__pb2.ShowCreateServiceOverrideRequest.FromString,
                    response_serializer=show__pb2.ShowCreateServiceOverrideResponse.SerializeToString,
            ),
            'CreateShow': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateShow,
                    request_deserializer=show__pb2.ShowCreateShowRequest.FromString,
                    response_serializer=show__pb2.ShowCreateShowResponse.SerializeToString,
            ),
            'CreateSubscription': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSubscription,
                    request_deserializer=show__pb2.ShowCreateSubscriptionRequest.FromString,
                    response_serializer=show__pb2.ShowCreateSubscriptionResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=show__pb2.ShowDeleteRequest.FromString,
                    response_serializer=show__pb2.ShowDeleteResponse.SerializeToString,
            ),
            'EnableBooking': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableBooking,
                    request_deserializer=show__pb2.ShowEnableBookingRequest.FromString,
                    response_serializer=show__pb2.ShowEnableBookingResponse.SerializeToString,
            ),
            'EnableDispatching': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableDispatching,
                    request_deserializer=show__pb2.ShowEnableDispatchingRequest.FromString,
                    response_serializer=show__pb2.ShowEnableDispatchingResponse.SerializeToString,
            ),
            'FindFilter': grpc.unary_unary_rpc_method_handler(
                    servicer.FindFilter,
                    request_deserializer=show__pb2.ShowFindFilterRequest.FromString,
                    response_serializer=show__pb2.ShowFindFilterResponse.SerializeToString,
            ),
            'FindShow': grpc.unary_unary_rpc_method_handler(
                    servicer.FindShow,
                    request_deserializer=show__pb2.ShowFindShowRequest.FromString,
                    response_serializer=show__pb2.ShowFindShowResponse.SerializeToString,
            ),
            'GetActiveShows': grpc.unary_unary_rpc_method_handler(
                    servicer.GetActiveShows,
                    request_deserializer=show__pb2.ShowGetActiveShowsRequest.FromString,
                    response_serializer=show__pb2.ShowGetActiveShowsResponse.SerializeToString,
            ),
            'GetDeeds': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeeds,
                    request_deserializer=show__pb2.ShowGetDeedsRequest.FromString,
                    response_serializer=show__pb2.ShowGetDeedsResponse.SerializeToString,
            ),
            'GetDepartment': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDepartment,
                    request_deserializer=show__pb2.ShowGetDepartmentRequest.FromString,
                    response_serializer=show__pb2.ShowGetDepartmentResponse.SerializeToString,
            ),
            'GetDepartments': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDepartments,
                    request_deserializer=show__pb2.ShowGetDepartmentsRequest.FromString,
                    response_serializer=show__pb2.ShowGetDepartmentsResponse.SerializeToString,
            ),
            'GetFilters': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFilters,
                    request_deserializer=show__pb2.ShowGetFiltersRequest.FromString,
                    response_serializer=show__pb2.ShowGetFiltersResponse.SerializeToString,
            ),
            'GetGroups': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGroups,
                    request_deserializer=show__pb2.ShowGetGroupsRequest.FromString,
                    response_serializer=show__pb2.ShowGetGroupsResponse.SerializeToString,
            ),
            'GetJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetJobs,
                    request_deserializer=show__pb2.ShowGetJobsRequest.FromString,
                    response_serializer=show__pb2.ShowGetJobsResponse.SerializeToString,
            ),
            'GetJobWhiteboard': grpc.unary_unary_rpc_method_handler(
                    servicer.GetJobWhiteboard,
                    request_deserializer=show__pb2.ShowGetJobWhiteboardRequest.FromString,
                    response_serializer=show__pb2.ShowGetJobWhiteboardResponse.SerializeToString,
            ),
            'GetRootGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRootGroup,
                    request_deserializer=show__pb2.ShowGetRootGroupRequest.FromString,
                    response_serializer=show__pb2.ShowGetRootGroupResponse.SerializeToString,
            ),
            'GetServiceOverride': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServiceOverride,
                    request_deserializer=show__pb2.ShowGetServiceOverrideRequest.FromString,
                    response_serializer=show__pb2.ShowGetServiceOverrideResponse.SerializeToString,
            ),
            'GetServiceOverrides': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServiceOverrides,
                    request_deserializer=show__pb2.ShowGetServiceOverridesRequest.FromString,
                    response_serializer=show__pb2.ShowGetServiceOverridesResponse.SerializeToString,
            ),
            'GetShows': grpc.unary_unary_rpc_method_handler(
                    servicer.GetShows,
                    request_deserializer=show__pb2.ShowGetShowsRequest.FromString,
                    response_serializer=show__pb2.ShowGetShowsResponse.SerializeToString,
            ),
            'GetSubscriptions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSubscriptions,
                    request_deserializer=show__pb2.ShowGetSubscriptionRequest.FromString,
                    response_serializer=show__pb2.ShowGetSubscriptionResponse.SerializeToString,
            ),
            'SetActive': grpc.unary_unary_rpc_method_handler(
                    servicer.SetActive,
                    request_deserializer=show__pb2.ShowSetActiveRequest.FromString,
                    response_serializer=show__pb2.ShowSetActiveResponse.SerializeToString,
            ),
            'SetCommentEmail': grpc.unary_unary_rpc_method_handler(
                    servicer.SetCommentEmail,
                    request_deserializer=show__pb2.ShowSetCommentEmailRequest.FromString,
                    response_serializer=show__pb2.ShowSetCommentEmailResponse.SerializeToString,
            ),
            'SetDefaultMaxCores': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDefaultMaxCores,
                    request_deserializer=show__pb2.ShowSetDefaultMaxCoresRequest.FromString,
                    response_serializer=show__pb2.ShowSetDefaultMaxCoresResponse.SerializeToString,
            ),
            'SetDefaultMinCores': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDefaultMinCores,
                    request_deserializer=show__pb2.ShowSetDefaultMinCoresRequest.FromString,
                    response_serializer=show__pb2.ShowSetDefaultMinCoresResponse.SerializeToString,
            ),
            'SetDefaultMaxGpus': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDefaultMaxGpus,
                    request_deserializer=show__pb2.ShowSetDefaultMaxGpusRequest.FromString,
                    response_serializer=show__pb2.ShowSetDefaultMaxGpusResponse.SerializeToString,
            ),
            'SetDefaultMinGpus': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDefaultMinGpus,
                    request_deserializer=show__pb2.ShowSetDefaultMinGpusRequest.FromString,
                    response_serializer=show__pb2.ShowSetDefaultMinGpusResponse.SerializeToString,
            ),
            'Archive': grpc.unary_unary_rpc_method_handler(
                    servicer.Archive,
                    request_deserializer=show__pb2.ShowArchiveRequest.FromString,
                    response_serializer=show__pb2.ShowArchiveResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'show.ShowInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ShowInterface(object):
    """Shows are the top level object for work.

    -------- Services --------]

    """

    @staticmethod
    def CreateFilter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/CreateFilter',
            show__pb2.ShowCreateFilterRequest.SerializeToString,
            show__pb2.ShowCreateFilterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOwner(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/CreateOwner',
            show__pb2.ShowCreateOwnerRequest.SerializeToString,
            show__pb2.ShowCreateOwnerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateServiceOverride(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/CreateServiceOverride',
            show__pb2.ShowCreateServiceOverrideRequest.SerializeToString,
            show__pb2.ShowCreateServiceOverrideResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateShow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/CreateShow',
            show__pb2.ShowCreateShowRequest.SerializeToString,
            show__pb2.ShowCreateShowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSubscription(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/CreateSubscription',
            show__pb2.ShowCreateSubscriptionRequest.SerializeToString,
            show__pb2.ShowCreateSubscriptionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/Delete',
            show__pb2.ShowDeleteRequest.SerializeToString,
            show__pb2.ShowDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableBooking(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/EnableBooking',
            show__pb2.ShowEnableBookingRequest.SerializeToString,
            show__pb2.ShowEnableBookingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableDispatching(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/EnableDispatching',
            show__pb2.ShowEnableDispatchingRequest.SerializeToString,
            show__pb2.ShowEnableDispatchingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FindFilter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/FindFilter',
            show__pb2.ShowFindFilterRequest.SerializeToString,
            show__pb2.ShowFindFilterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FindShow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/FindShow',
            show__pb2.ShowFindShowRequest.SerializeToString,
            show__pb2.ShowFindShowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetActiveShows(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetActiveShows',
            show__pb2.ShowGetActiveShowsRequest.SerializeToString,
            show__pb2.ShowGetActiveShowsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeeds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetDeeds',
            show__pb2.ShowGetDeedsRequest.SerializeToString,
            show__pb2.ShowGetDeedsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDepartment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetDepartment',
            show__pb2.ShowGetDepartmentRequest.SerializeToString,
            show__pb2.ShowGetDepartmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDepartments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetDepartments',
            show__pb2.ShowGetDepartmentsRequest.SerializeToString,
            show__pb2.ShowGetDepartmentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFilters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetFilters',
            show__pb2.ShowGetFiltersRequest.SerializeToString,
            show__pb2.ShowGetFiltersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGroups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetGroups',
            show__pb2.ShowGetGroupsRequest.SerializeToString,
            show__pb2.ShowGetGroupsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetJobs',
            show__pb2.ShowGetJobsRequest.SerializeToString,
            show__pb2.ShowGetJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetJobWhiteboard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetJobWhiteboard',
            show__pb2.ShowGetJobWhiteboardRequest.SerializeToString,
            show__pb2.ShowGetJobWhiteboardResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRootGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetRootGroup',
            show__pb2.ShowGetRootGroupRequest.SerializeToString,
            show__pb2.ShowGetRootGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServiceOverride(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetServiceOverride',
            show__pb2.ShowGetServiceOverrideRequest.SerializeToString,
            show__pb2.ShowGetServiceOverrideResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServiceOverrides(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetServiceOverrides',
            show__pb2.ShowGetServiceOverridesRequest.SerializeToString,
            show__pb2.ShowGetServiceOverridesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetShows(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetShows',
            show__pb2.ShowGetShowsRequest.SerializeToString,
            show__pb2.ShowGetShowsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSubscriptions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetSubscriptions',
            show__pb2.ShowGetSubscriptionRequest.SerializeToString,
            show__pb2.ShowGetSubscriptionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetActive(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/SetActive',
            show__pb2.ShowSetActiveRequest.SerializeToString,
            show__pb2.ShowSetActiveResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetCommentEmail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/SetCommentEmail',
            show__pb2.ShowSetCommentEmailRequest.SerializeToString,
            show__pb2.ShowSetCommentEmailResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDefaultMaxCores(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/SetDefaultMaxCores',
            show__pb2.ShowSetDefaultMaxCoresRequest.SerializeToString,
            show__pb2.ShowSetDefaultMaxCoresResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDefaultMinCores(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/SetDefaultMinCores',
            show__pb2.ShowSetDefaultMinCoresRequest.SerializeToString,
            show__pb2.ShowSetDefaultMinCoresResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDefaultMaxGpus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/SetDefaultMaxGpus',
            show__pb2.ShowSetDefaultMaxGpusRequest.SerializeToString,
            show__pb2.ShowSetDefaultMaxGpusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDefaultMinGpus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/SetDefaultMinGpus',
            show__pb2.ShowSetDefaultMinGpusRequest.SerializeToString,
            show__pb2.ShowSetDefaultMinGpusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Archive(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/Archive',
            show__pb2.ShowArchiveRequest.SerializeToString,
            show__pb2.ShowArchiveResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import rqd_pb2 as rqd__pb2


class RqdInterfaceStub(object):
    """Interface for issuing commands to an RQD instance.

    -------- Services --------]

    Implemented by the Rqd server. Called by cuebot and tools.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetRunFrame = channel.unary_unary(
                '/rqd.RqdInterface/GetRunFrame',
                request_serializer=rqd__pb2.RqdStaticGetRunFrameRequest.SerializeToString,
                response_deserializer=rqd__pb2.RqdStaticGetRunFrameResponse.FromString,
                )
        self.GetRunningFrameStatus = channel.unary_unary(
                '/rqd.RqdInterface/GetRunningFrameStatus',
                request_serializer=rqd__pb2.RqdStaticGetRunningFrameStatusRequest.SerializeToString,
                response_deserializer=rqd__pb2.RqdStaticGetRunningFrameStatusResponse.FromString,
                )
        self.KillRunningFrame = channel.unary_unary(
                '/rqd.RqdInterface/KillRunningFrame',
                request_serializer=rqd__pb2.RqdStaticKillRunningFrameRequest.SerializeToString,
                response_deserializer=rqd__pb2.RqdStaticKillRunningFrameResponse.FromString,
                )
        self.LaunchFrame = channel.unary_unary(
                '/rqd.RqdInterface/LaunchFrame',
                request_serializer=rqd__pb2.RqdStaticLaunchFrameRequest.SerializeToString,
                response_deserializer=rqd__pb2.RqdStaticLaunchFrameResponse.FromString,
                )
        self.Lock = channel.unary_unary(
                '/rqd.RqdInterface/Lock',
                request_serializer=rqd__pb2.RqdStaticLockRequest.SerializeToString,
                response_deserializer=rqd__pb2.RqdStaticLockResponse.FromString,
                )
        self.LockAll = channel.unary_unary(
                '/rqd.RqdInterface/LockAll',
                request_serializer=rqd__pb2.RqdStaticLockAllRequest.SerializeToString,
                response_deserializer=rqd__pb2.RqdStaticLockAllResponse.FromString,
                )
        self.NimbyOff = channel.unary_unary(
                '/rqd.RqdInterface/NimbyOff',
                request_serializer=rqd__pb2.RqdStaticNimbyOffRequest.SerializeToString,
                response_deserializer=rqd__pb2.RqdStaticNimbyOffResponse.FromString,
                )
        self.NimbyOn = channel.unary_unary(
                '/rqd.RqdInterface/NimbyOn',
                request_serializer=rqd__pb2.RqdStaticNimbyOnRequest.SerializeToString,
                response_deserializer=rqd__pb2.RqdStaticNimbyOnResponse.FromString,
                )
        self.RebootIdle = channel.unary_unary(
                '/rqd.RqdInterface/RebootIdle',
                request_serializer=rqd__pb2.RqdStaticRebootIdleRequest.SerializeToString,
                response_deserializer=rqd__pb2.RqdStaticRebootIdleResponse.FromString,
                )
        self.RebootNow = channel.unary_unary(
                '/rqd.RqdInterface/RebootNow',
                request_serializer=rqd__pb2.RqdStaticRebootNowRequest.SerializeToString,
                response_deserializer=rqd__pb2.RqdStaticRebootNowResponse.FromString,
                )
        self.ReportStatus = channel.unary_unary(
                '/rqd.RqdInterface/ReportStatus',
                request_serializer=rqd__pb2.RqdStaticReportStatusRequest.SerializeToString,
                response_deserializer=rqd__pb2.RqdStaticReportStatusResponse.FromString,
                )
        self.RestartRqdIdle = channel.unary_unary(
                '/rqd.RqdInterface/RestartRqdIdle',
                request_serializer=rqd__pb2.RqdStaticRestartIdleRequest.SerializeToString,
                response_deserializer=rqd__pb2.RqdStaticRestartIdleResponse.FromString,
                )
        self.RestartRqdNow = channel.unary_unary(
                '/rqd.RqdInterface/RestartRqdNow',
                request_serializer=rqd__pb2.RqdStaticRestartNowRequest.SerializeToString,
                response_deserializer=rqd__pb2.RqdStaticRestartNowResponse.FromString,
                )
        self.ShutdownRqdIdle = channel.unary_unary(
                '/rqd.RqdInterface/ShutdownRqdIdle',
                request_serializer=rqd__pb2.RqdStaticShutdownIdleRequest.SerializeToString,
                response_deserializer=rqd__pb2.RqdStaticShutdownIdleResponse.FromString,
                )
        self.ShutdownRqdNow = channel.unary_unary(
                '/rqd.RqdInterface/ShutdownRqdNow',
                request_serializer=rqd__pb2.RqdStaticShutdownNowRequest.SerializeToString,
                response_deserializer=rqd__pb2.RqdStaticShutdownNowResponse.FromString,
                )
        self.Unlock = channel.unary_unary(
                '/rqd.RqdInterface/Unlock',
                request_serializer=rqd__pb2.RqdStaticUnlockRequest.SerializeToString,
                response_deserializer=rqd__pb2.RqdStaticUnlockResponse.FromString,
                )
        self.UnlockAll = channel.unary_unary(
                '/rqd.RqdInterface/UnlockAll',
                request_serializer=rqd__pb2.RqdStaticUnlockAllRequest.SerializeToString,
                response_deserializer=rqd__pb2.RqdStaticUnlockAllResponse.FromString,
                )


class RqdInterfaceServicer(object):
    """Interface for issuing commands to an RQD instance.

    -------- Services --------]

    Implemented by the Rqd server. Called by cuebot and tools.
    """

    def GetRunFrame(self, request, context):
        """[Deprecated] Return the RunFrame by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRunningFrameStatus(self, request, context):
        """Return the RunningFrameStatus report
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def KillRunningFrame(self, request, context):
        """Kill the running frame by frame id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LaunchFrame(self, request, context):
        """Launch a new running frame
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Lock(self, request, context):
        """Lock a number of cores
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LockAll(self, request, context):
        """Lock all
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NimbyOff(self, request, context):
        """Disable NIMBY on host
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NimbyOn(self, request, context):
        """Enable NIMBY on host
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RebootIdle(self, request, context):
        """Reboot the host when it becomes idle
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RebootNow(self, request, context):
        """[Deprecated] Reboot the host now
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReportStatus(self, request, context):
        """Return the HostReport
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RestartRqdIdle(self, request, context):
        """[Deprecated] Restart the rqd process when it becomes idle
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RestartRqdNow(self, request, context):
        """[Deprecated] Restart rqd process now
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ShutdownRqdIdle(self, request, context):
        """[Deprecated] Turn off rqd when it becomes idle
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ShutdownRqdNow(self, request, context):
        """Stop rqd now
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Unlock(self, request, context):
        """Unlock a number of cores
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnlockAll(self, request, context):
        """Unlock all cores
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RqdInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetRunFrame': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRunFrame,
                    request_deserializer=rqd__pb2.RqdStaticGetRunFrameRequest.FromString,
                    response_serializer=rqd__pb2.RqdStaticGetRunFrameResponse.SerializeToString,
            ),
            'GetRunningFrameStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRunningFrameStatus,
                    request_deserializer=rqd__pb2.RqdStaticGetRunningFrameStatusRequest.FromString,
                    response_serializer=rqd__pb2.RqdStaticGetRunningFrameStatusResponse.SerializeToString,
            ),
            'KillRunningFrame': grpc.unary_unary_rpc_method_handler(
                    servicer.KillRunningFrame,
                    request_deserializer=rqd__pb2.RqdStaticKillRunningFrameRequest.FromString,
                    response_serializer=rqd__pb2.RqdStaticKillRunningFrameResponse.SerializeToString,
            ),
            'LaunchFrame': grpc.unary_unary_rpc_method_handler(
                    servicer.LaunchFrame,
                    request_deserializer=rqd__pb2.RqdStaticLaunchFrameRequest.FromString,
                    response_serializer=rqd__pb2.RqdStaticLaunchFrameResponse.SerializeToString,
            ),
            'Lock': grpc.unary_unary_rpc_method_handler(
                    servicer.Lock,
                    request_deserializer=rqd__pb2.RqdStaticLockRequest.FromString,
                    response_serializer=rqd__pb2.RqdStaticLockResponse.SerializeToString,
            ),
            'LockAll': grpc.unary_unary_rpc_method_handler(
                    servicer.LockAll,
                    request_deserializer=rqd__pb2.RqdStaticLockAllRequest.FromString,
                    response_serializer=rqd__pb2.RqdStaticLockAllResponse.SerializeToString,
            ),
            'NimbyOff': grpc.unary_unary_rpc_method_handler(
                    servicer.NimbyOff,
                    request_deserializer=rqd__pb2.RqdStaticNimbyOffRequest.FromString,
                    response_serializer=rqd__pb2.RqdStaticNimbyOffResponse.SerializeToString,
            ),
            'NimbyOn': grpc.unary_unary_rpc_method_handler(
                    servicer.NimbyOn,
                    request_deserializer=rqd__pb2.RqdStaticNimbyOnRequest.FromString,
                    response_serializer=rqd__pb2.RqdStaticNimbyOnResponse.SerializeToString,
            ),
            'RebootIdle': grpc.unary_unary_rpc_method_handler(
                    servicer.RebootIdle,
                    request_deserializer=rqd__pb2.RqdStaticRebootIdleRequest.FromString,
                    response_serializer=rqd__pb2.RqdStaticRebootIdleResponse.SerializeToString,
            ),
            'RebootNow': grpc.unary_unary_rpc_method_handler(
                    servicer.RebootNow,
                    request_deserializer=rqd__pb2.RqdStaticRebootNowRequest.FromString,
                    response_serializer=rqd__pb2.RqdStaticRebootNowResponse.SerializeToString,
            ),
            'ReportStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportStatus,
                    request_deserializer=rqd__pb2.RqdStaticReportStatusRequest.FromString,
                    response_serializer=rqd__pb2.RqdStaticReportStatusResponse.SerializeToString,
            ),
            'RestartRqdIdle': grpc.unary_unary_rpc_method_handler(
                    servicer.RestartRqdIdle,
                    request_deserializer=rqd__pb2.RqdStaticRestartIdleRequest.FromString,
                    response_serializer=rqd__pb2.RqdStaticRestartIdleResponse.SerializeToString,
            ),
            'RestartRqdNow': grpc.unary_unary_rpc_method_handler(
                    servicer.RestartRqdNow,
                    request_deserializer=rqd__pb2.RqdStaticRestartNowRequest.FromString,
                    response_serializer=rqd__pb2.RqdStaticRestartNowResponse.SerializeToString,
            ),
            'ShutdownRqdIdle': grpc.unary_unary_rpc_method_handler(
                    servicer.ShutdownRqdIdle,
                    request_deserializer=rqd__pb2.RqdStaticShutdownIdleRequest.FromString,
                    response_serializer=rqd__pb2.RqdStaticShutdownIdleResponse.SerializeToString,
            ),
            'ShutdownRqdNow': grpc.unary_unary_rpc_method_handler(
                    servicer.ShutdownRqdNow,
                    request_deserializer=rqd__pb2.RqdStaticShutdownNowRequest.FromString,
                    response_serializer=rqd__pb2.RqdStaticShutdownNowResponse.SerializeToString,
            ),
            'Unlock': grpc.unary_unary_rpc_method_handler(
                    servicer.Unlock,
                    request_deserializer=rqd__pb2.RqdStaticUnlockRequest.FromString,
                    response_serializer=rqd__pb2.RqdStaticUnlockResponse.SerializeToString,
            ),
            'UnlockAll': grpc.unary_unary_rpc_method_handler(
                    servicer.UnlockAll,
                    request_deserializer=rqd__pb2.RqdStaticUnlockAllRequest.FromString,
                    response_serializer=rqd__pb2.RqdStaticUnlockAllResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'rqd.RqdInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RqdInterface(object):
    """Interface for issuing commands to an RQD instance.

    -------- Services --------]

    Implemented by the Rqd server. Called by cuebot and tools.
    """

    @staticmethod
    def GetRunFrame(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rqd.RqdInterface/GetRunFrame',
            rqd__pb2.RqdStaticGetRunFrameRequest.SerializeToString,
            rqd__pb2.RqdStaticGetRunFrameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRunningFrameStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rqd.RqdInterface/GetRunningFrameStatus',
            rqd__pb2.RqdStaticGetRunningFrameStatusRequest.SerializeToString,
            rqd__pb2.RqdStaticGetRunningFrameStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def KillRunningFrame(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rqd.RqdInterface/KillRunningFrame',
            rqd__pb2.RqdStaticKillRunningFrameRequest.SerializeToString,
            rqd__pb2.RqdStaticKillRunningFrameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LaunchFrame(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rqd.RqdInterface/LaunchFrame',
            rqd__pb2.RqdStaticLaunchFrameRequest.SerializeToString,
            rqd__pb2.RqdStaticLaunchFrameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Lock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rqd.RqdInterface/Lock',
            rqd__pb2.RqdStaticLockRequest.SerializeToString,
            rqd__pb2.RqdStaticLockResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LockAll(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rqd.RqdInterface/LockAll',
            rqd__pb2.RqdStaticLockAllRequest.SerializeToString,
            rqd__pb2.RqdStaticLockAllResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NimbyOff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rqd.RqdInterface/NimbyOff',
            rqd__pb2.RqdStaticNimbyOffRequest.SerializeToString,
            rqd__pb2.RqdStaticNimbyOffResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NimbyOn(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rqd.RqdInterface/NimbyOn',
            rqd__pb2.RqdStaticNimbyOnRequest.SerializeToString,
            rqd__pb2.RqdStaticNimbyOnResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RebootIdle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rqd.RqdInterface/RebootIdle',
            rqd__pb2.RqdStaticRebootIdleRequest.SerializeToString,
            rqd__pb2.RqdStaticRebootIdleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RebootNow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rqd.RqdInterface/RebootNow',
            rqd__pb2.RqdStaticRebootNowRequest.SerializeToString,
            rqd__pb2.RqdStaticRebootNowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReportStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rqd.RqdInterface/ReportStatus',
            rqd__pb2.RqdStaticReportStatusRequest.SerializeToString,
            rqd__pb2.RqdStaticReportStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RestartRqdIdle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rqd.RqdInterface/RestartRqdIdle',
            rqd__pb2.RqdStaticRestartIdleRequest.SerializeToString,
            rqd__pb2.RqdStaticRestartIdleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RestartRqdNow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rqd.RqdInterface/RestartRqdNow',
            rqd__pb2.RqdStaticRestartNowRequest.SerializeToString,
            rqd__pb2.RqdStaticRestartNowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ShutdownRqdIdle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rqd.RqdInterface/ShutdownRqdIdle',
            rqd__pb2.RqdStaticShutdownIdleRequest.SerializeToString,
            rqd__pb2.RqdStaticShutdownIdleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ShutdownRqdNow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rqd.RqdInterface/ShutdownRqdNow',
            rqd__pb2.RqdStaticShutdownNowRequest.SerializeToString,
            rqd__pb2.RqdStaticShutdownNowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Unlock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rqd.RqdInterface/Unlock',
            rqd__pb2.RqdStaticUnlockRequest.SerializeToString,
            rqd__pb2.RqdStaticUnlockResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnlockAll(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rqd.RqdInterface/UnlockAll',
            rqd__pb2.RqdStaticUnlockAllRequest.SerializeToString,
            rqd__pb2.RqdStaticUnlockAllResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class RunningFrameStub(object):
    """Implemented by the Rqd server. Called by cuebot and tools.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Kill = channel.unary_unary(
                '/rqd.RunningFrame/Kill',
                request_serializer=rqd__pb2.RunningFrameKillRequest.SerializeToString,
                response_deserializer=rqd__pb2.RunningFrameKillResponse.FromString,
                )
        self.Status = channel.unary_unary(
                '/rqd.RunningFrame/Status',
                request_serializer=rqd__pb2.RunningFrameStatusRequest.SerializeToString,
                response_deserializer=rqd__pb2.RunningFrameStatusResponse.FromString,
                )


class RunningFrameServicer(object):
    """Implemented by the Rqd server. Called by cuebot and tools.
    """

    def Kill(self, request, context):
        """Kill the provided running frame
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Status(self, request, context):
        """Get the status of the running frame
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RunningFrameServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Kill': grpc.unary_unary_rpc_method_handler(
                    servicer.Kill,
                    request_deserializer=rqd__pb2.RunningFrameKillRequest.FromString,
                    response_serializer=rqd__pb2.RunningFrameKillResponse.SerializeToString,
            ),
            'Status': grpc.unary_unary_rpc_method_handler(
                    servicer.Status,
                    request_deserializer=rqd__pb2.RunningFrameStatusRequest.FromString,
                    response_serializer=rqd__pb2.RunningFrameStatusResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'rqd.RunningFrame', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RunningFrame(object):
    """Implemented by the Rqd server. Called by cuebot and tools.
    """

    @staticmethod
    def Kill(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rqd.RunningFrame/Kill',
            rqd__pb2.RunningFrameKillRequest.SerializeToString,
            rqd__pb2.RunningFrameKillResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Status(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rqd.RunningFrame/Status',
            rqd__pb2.RunningFrameStatusRequest.SerializeToString,
            rqd__pb2.RunningFrameStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import report_pb2 as report__pb2


class RqdReportInterfaceStub(object):
    """Interface to handle RQD pings.

    -------- Services --------]

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ReportRqdStartup = channel.unary_unary(
                '/report.RqdReportInterface/ReportRqdStartup',
                request_serializer=report__pb2.RqdReportRqdStartupRequest.SerializeToString,
                response_deserializer=report__pb2.RqdReportRqdStartupResponse.FromString,
                )
        self.ReportRunningFrameCompletion = channel.unary_unary(
                '/report.RqdReportInterface/ReportRunningFrameCompletion',
                request_serializer=report__pb2.RqdReportRunningFrameCompletionRequest.SerializeToString,
                response_deserializer=report__pb2.RqdReportRunningFrameCompletionResponse.FromString,
                )
        self.ReportStatus = channel.unary_unary(
                '/report.RqdReportInterface/ReportStatus',
                request_serializer=report__pb2.RqdReportStatusRequest.SerializeToString,
                response_deserializer=report__pb2.RqdReportStatusResponse.FromString,
                )


class RqdReportInterfaceServicer(object):
    """Interface to handle RQD pings.

    -------- Services --------]

    """

    def ReportRqdStartup(self, request, context):
        """Send in when RQD starts up to announce new idle procs to the cue.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReportRunningFrameCompletion(self, request, context):
        """Reports in a running frame
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReportStatus(self, request, context):
        """An incremental status report sent by RQD
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RqdReportInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ReportRqdStartup': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportRqdStartup,
                    request_deserializer=report__pb2.RqdReportRqdStartupRequest.FromString,
                    response_serializer=report__pb2.RqdReportRqdStartupResponse.SerializeToString,
            ),
            'ReportRunningFrameCompletion': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportRunningFrameCompletion,
                    request_deserializer=report__pb2.RqdReportRunningFrameCompletionRequest.FromString,
                    response_serializer=report__pb2.RqdReportRunningFrameCompletionResponse.SerializeToString,
            ),
            'ReportStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportStatus,
                    request_deserializer=report__pb2.RqdReportStatusRequest.FromString,
                    response_serializer=report__pb2.RqdReportStatusResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'report.RqdReportInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RqdReportInterface(object):
    """Interface to handle RQD pings.

    -------- Services --------]

    """

    @staticmethod
    def ReportRqdStartup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/report.RqdReportInterface/ReportRqdStartup',
            report__pb2.RqdReportRqdStartupRequest.SerializeToString,
            report__pb2.RqdReportRqdStartupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReportRunningFrameCompletion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/report.RqdReportInterface/ReportRunningFrameCompletion',
            report__pb2.RqdReportRunningFrameCompletionRequest.SerializeToString,
            report__pb2.RqdReportRunningFrameCompletionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReportStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/report.RqdReportInterface/ReportStatus',
            report__pb2.RqdReportStatusRequest.SerializeToString,
            report__pb2.RqdReportStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: comment.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rcomment.proto\x12\x07\x63omment\"X\n\x07\x43omment\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x05\x12\x0c\n\x04user\x18\x03 \x01(\t\x12\x0f\n\x07subject\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"0\n\nCommentSeq\x12\"\n\x08\x63omments\x18\x01 \x03(\x0b\x32\x10.comment.Comment\"9\n\x14\x43ommentDeleteRequest\x12!\n\x07\x63omment\x18\x01 \x01(\x0b\x32\x10.comment.Comment\"\x17\n\x15\x43ommentDeleteResponse\"7\n\x12\x43ommentSaveRequest\x12!\n\x07\x63omment\x18\x01 \x01(\x0b\x32\x10.comment.Comment\"\x15\n\x13\x43ommentSaveResponse2\x9e\x01\n\x10\x43ommentInterface\x12G\n\x06\x44\x65lete\x12\x1d.comment.CommentDeleteRequest\x1a\x1e.comment.CommentDeleteResponse\x12\x41\n\x04Save\x12\x1b.comment.CommentSaveRequest\x1a\x1c.comment.CommentSaveResponseB=\n!com.imageworks.spcue.grpc.commentP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'comment_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.imageworks.spcue.grpc.commentP\001Z\026opencue_gateway/gen/go'
  _globals['_COMMENT']._serialized_start=26
  _globals['_COMMENT']._serialized_end=114
  _globals['_COMMENTSEQ']._serialized_start=116
  _globals['_COMMENTSEQ']._serialized_end=164
  _globals['_COMMENTDELETEREQUEST']._serialized_start=166
  _globals['_COMMENTDELETEREQUEST']._serialized_end=223
  _globals['_COMMENTDELETERESPONSE']._serialized_start=225
  _globals['_COMMENTDELETERESPONSE']._serialized_end=248
  _globals['_COMMENTSAVEREQUEST']._serialized_start=250
  _globals['_COMMENTSAVEREQUEST']._serialized_end=305
  _globals['_COMMENTSAVERESPONSE']._serialized_start=307
  _globals['_COMMENTSAVERESPONSE']._serialized_end=328
  _globals['_COMMENTINTERFACE']._serialized_start=331
  _globals['_COMMENTINTERFACE']._serialized_end=489
# @@protoc_insertion_point(module_scope)


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import filter_pb2 as filter__pb2


class ActionInterfaceStub(object):
    """-------- Services --------

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Commit = channel.unary_unary(
                '/filter.ActionInterface/Commit',
                request_serializer=filter__pb2.ActionCommitRequest.SerializeToString,
                response_deserializer=filter__pb2.ActionCommitResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/filter.ActionInterface/Delete',
                request_serializer=filter__pb2.ActionDeleteRequest.SerializeToString,
                response_deserializer=filter__pb2.ActionDeleteResponse.FromString,
                )
        self.GetParentFilter = channel.unary_unary(
                '/filter.ActionInterface/GetParentFilter',
                request_serializer=filter__pb2.ActionGetParentFilterRequest.SerializeToString,
                response_deserializer=filter__pb2.ActionGetParentFilterResponse.FromString,
                )


class ActionInterfaceServicer(object):
    """-------- Services --------

    """

    def Commit(self, request, context):
        """Sets new properties for the [Action] on the server side using a [ActionData] object.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Delete this [Action]
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetParentFilter(self, request, context):
        """Returns the [Filter] this action is part of.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ActionInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Commit': grpc.unary_unary_rpc_method_handler(
                    servicer.Commit,
                    request_deserializer=filter__pb2.ActionCommitRequest.FromString,
                    response_serializer=filter__pb2.ActionCommitResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=filter__pb2.ActionDeleteRequest.FromString,
                    response_serializer=filter__pb2.ActionDeleteResponse.SerializeToString,
            ),
            'GetParentFilter': grpc.unary_unary_rpc_method_handler(
                    servicer.GetParentFilter,
                    request_deserializer=filter__pb2.ActionGetParentFilterRequest.FromString,
                    response_serializer=filter__pb2.ActionGetParentFilterResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'filter.ActionInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ActionInterface(object):
    """-------- Services --------

    """

    @staticmethod
    def Commit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.ActionInterface/Commit',
            filter__pb2.ActionCommitRequest.SerializeToString,
            filter__pb2.ActionCommitResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.ActionInterface/Delete',
            filter__pb2.ActionDeleteRequest.SerializeToString,
            filter__pb2.ActionDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetParentFilter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.ActionInterface/GetParentFilter',
            filter__pb2.ActionGetParentFilterRequest.SerializeToString,
            filter__pb2.ActionGetParentFilterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class FilterInterfaceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateAction = channel.unary_unary(
                '/filter.FilterInterface/CreateAction',
                request_serializer=filter__pb2.FilterCreateActionRequest.SerializeToString,
                response_deserializer=filter__pb2.FilterCreateActionResponse.FromString,
                )
        self.CreateMatcher = channel.unary_unary(
                '/filter.FilterInterface/CreateMatcher',
                request_serializer=filter__pb2.FilterCreateMatcherRequest.SerializeToString,
                response_deserializer=filter__pb2.FilterCreateMatcherResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/filter.FilterInterface/Delete',
                request_serializer=filter__pb2.FilterDeleteRequest.SerializeToString,
                response_deserializer=filter__pb2.FilterDeleteResponse.FromString,
                )
        self.FindFilter = channel.unary_unary(
                '/filter.FilterInterface/FindFilter',
                request_serializer=filter__pb2.FilterFindFilterRequest.SerializeToString,
                response_deserializer=filter__pb2.FilterFindFilterResponse.FromString,
                )
        self.GetActions = channel.unary_unary(
                '/filter.FilterInterface/GetActions',
                request_serializer=filter__pb2.FilterGetActionsRequest.SerializeToString,
                response_deserializer=filter__pb2.FilterGetActionsResponse.FromString,
                )
        self.GetMatchers = channel.unary_unary(
                '/filter.FilterInterface/GetMatchers',
                request_serializer=filter__pb2.FilterGetMatchersRequest.SerializeToString,
                response_deserializer=filter__pb2.FilterGetMatchersResponse.FromString,
                )
        self.LowerOrder = channel.unary_unary(
                '/filter.FilterInterface/LowerOrder',
                request_serializer=filter__pb2.FilterLowerOrderRequest.SerializeToString,
                response_deserializer=filter__pb2.FilterLowerOrderResponse.FromString,
                )
        self.OrderFirst = channel.unary_unary(
                '/filter.FilterInterface/OrderFirst',
                request_serializer=filter__pb2.FilterOrderFirstRequest.SerializeToString,
                response_deserializer=filter__pb2.FilterOrderFirstResponse.FromString,
                )
        self.OrderLast = channel.unary_unary(
                '/filter.FilterInterface/OrderLast',
                request_serializer=filter__pb2.FilterOrderLastRequest.SerializeToString,
                response_deserializer=filter__pb2.FilterOrderLastResponse.FromString,
                )
        self.RaiseOrder = channel.unary_unary(
                '/filter.FilterInterface/RaiseOrder',
                request_serializer=filter__pb2.FilterRaiseOrderRequest.SerializeToString,
                response_deserializer=filter__pb2.FilterRaiseOrderResponse.FromString,
                )
        self.RunFilterOnGroup = channel.unary_unary(
                '/filter.FilterInterface/RunFilterOnGroup',
                request_serializer=filter__pb2.FilterRunFilterOnGroupRequest.SerializeToString,
                response_deserializer=filter__pb2.FilterRunFilterOnGroupResponse.FromString,
                )
        self.RunFilterOnJobs = channel.unary_unary(
                '/filter.FilterInterface/RunFilterOnJobs',
                request_serializer=filter__pb2.FilterRunFilterOnJobsRequest.SerializeToString,
                response_deserializer=filter__pb2.FilterRunFilterOnJobsResponse.FromString,
                )
        self.SetEnabled = channel.unary_unary(
                '/filter.FilterInterface/SetEnabled',
                request_serializer=filter__pb2.FilterSetEnabledRequest.SerializeToString,
                response_deserializer=filter__pb2.FilterSetEnabledResponse.FromString,
                )
        self.SetName = channel.unary_unary(
                '/filter.FilterInterface/SetName',
                request_serializer=filter__pb2.FilterSetNameRequest.SerializeToString,
                response_deserializer=filter__pb2.FilterSetNameResponse.FromString,
                )
        self.SetOrder = channel.unary_unary(
                '/filter.FilterInterface/SetOrder',
                request_serializer=filter__pb2.FilterSetOrderRequest.SerializeToString,
                response_deserializer=filter__pb2.FilterSetOrderResponse.FromString,
                )
        self.SetType = channel.unary_unary(
                '/filter.FilterInterface/SetType',
                request_serializer=filter__pb2.FilterSetTypeRequest.SerializeToString,
                response_deserializer=filter__pb2.FilterSetTypeResponse.FromString,
                )


class FilterInterfaceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateAction(self, request, context):
        """Creates a new [Action] that will execute for this filter.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateMatcher(self, request, context):
        """Creates a new [Matcher] for this filter.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Delete this filter.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindFilter(self, request, context):
        """Find a filter by it's show and name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetActions(self, request, context):
        """Returns a list of [Action]s configured for this filter.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMatchers(self, request, context):
        """Returns a list of [Matcher]s configured for this filter
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LowerOrder(self, request, context):
        """Lowers the order of the filter, this makes it run after the next filter
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OrderFirst(self, request, context):
        """Moves the filter to first in the order list.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OrderLast(self, request, context):
        """Moves the filter to last in the order list.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RaiseOrder(self, request, context):
        """Raises the order of the filter, this makes it run before the previous filter.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunFilterOnGroup(self, request, context):
        """Executes the filter on a specified group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunFilterOnJobs(self, request, context):
        """Executes the filter on a specified sequence of jobs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetEnabled(self, request, context):
        """Set the filter to enabled or disabled
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetName(self, request, context):
        """Set the filter name.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetOrder(self, request, context):
        """Directly sets the order of the filter.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetType(self, request, context):
        """Set the type of the filter. See FilterType
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FilterInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateAction': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAction,
                    request_deserializer=filter__pb2.FilterCreateActionRequest.FromString,
                    response_serializer=filter__pb2.FilterCreateActionResponse.SerializeToString,
            ),
            'CreateMatcher': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateMatcher,
                    request_deserializer=filter__pb2.FilterCreateMatcherRequest.FromString,
                    response_serializer=filter__pb2.FilterCreateMatcherResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=filter__pb2.FilterDeleteRequest.FromString,
                    response_serializer=filter__pb2.FilterDeleteResponse.SerializeToString,
            ),
            'FindFilter': grpc.unary_unary_rpc_method_handler(
                    servicer.FindFilter,
                    request_deserializer=filter__pb2.FilterFindFilterRequest.FromString,
                    response_serializer=filter__pb2.FilterFindFilterResponse.SerializeToString,
            ),
            'GetActions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetActions,
                    request_deserializer=filter__pb2.FilterGetActionsRequest.FromString,
                    response_serializer=filter__pb2.FilterGetActionsResponse.SerializeToString,
            ),
            'GetMatchers': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMatchers,
                    request_deserializer=filter__pb2.FilterGetMatchersRequest.FromString,
                    response_serializer=filter__pb2.FilterGetMatchersResponse.SerializeToString,
            ),
            'LowerOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.LowerOrder,
                    request_deserializer=filter__pb2.FilterLowerOrderRequest.FromString,
                    response_serializer=filter__pb2.FilterLowerOrderResponse.SerializeToString,
            ),
            'OrderFirst': grpc.unary_unary_rpc_method_handler(
                    servicer.OrderFirst,
                    request_deserializer=filter__pb2.FilterOrderFirstRequest.FromString,
                    response_serializer=filter__pb2.FilterOrderFirstResponse.SerializeToString,
            ),
            'OrderLast': grpc.unary_unary_rpc_method_handler(
                    servicer.OrderLast,
                    request_deserializer=filter__pb2.FilterOrderLastRequest.FromString,
                    response_serializer=filter__pb2.FilterOrderLastResponse.SerializeToString,
            ),
            'RaiseOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.RaiseOrder,
                    request_deserializer=filter__pb2.FilterRaiseOrderRequest.FromString,
                    response_serializer=filter__pb2.FilterRaiseOrderResponse.SerializeToString,
            ),
            'RunFilterOnGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.RunFilterOnGroup,
                    request_deserializer=filter__pb2.FilterRunFilterOnGroupRequest.FromString,
                    response_serializer=filter__pb2.FilterRunFilterOnGroupResponse.SerializeToString,
            ),
            'RunFilterOnJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.RunFilterOnJobs,
                    request_deserializer=filter__pb2.FilterRunFilterOnJobsRequest.FromString,
                    response_serializer=filter__pb2.FilterRunFilterOnJobsResponse.SerializeToString,
            ),
            'SetEnabled': grpc.unary_unary_rpc_method_handler(
                    servicer.SetEnabled,
                    request_deserializer=filter__pb2.FilterSetEnabledRequest.FromString,
                    response_serializer=filter__pb2.FilterSetEnabledResponse.SerializeToString,
            ),
            'SetName': grpc.unary_unary_rpc_method_handler(
                    servicer.SetName,
                    request_deserializer=filter__pb2.FilterSetNameRequest.FromString,
                    response_serializer=filter__pb2.FilterSetNameResponse.SerializeToString,
            ),
            'SetOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.SetOrder,
                    request_deserializer=filter__pb2.FilterSetOrderRequest.FromString,
                    response_serializer=filter__pb2.FilterSetOrderResponse.SerializeToString,
            ),
            'SetType': grpc.unary_unary_rpc_method_handler(
                    servicer.SetType,
                    request_deserializer=filter__pb2.FilterSetTypeRequest.FromString,
                    response_serializer=filter__pb2.FilterSetTypeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'filter.FilterInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FilterInterface(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateAction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.FilterInterface/CreateAction',
            filter__pb2.FilterCreateActionRequest.SerializeToString,
            filter__pb2.FilterCreateActionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateMatcher(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.FilterInterface/CreateMatcher',
            filter__pb2.FilterCreateMatcherRequest.SerializeToString,
            filter__pb2.FilterCreateMatcherResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.FilterInterface/Delete',
            filter__pb2.FilterDeleteRequest.SerializeToString,
            filter__pb2.FilterDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FindFilter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.FilterInterface/FindFilter',
            filter__pb2.FilterFindFilterRequest.SerializeToString,
            filter__pb2.FilterFindFilterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetActions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.FilterInterface/GetActions',
            filter__pb2.FilterGetActionsRequest.SerializeToString,
            filter__pb2.FilterGetActionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMatchers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.FilterInterface/GetMatchers',
            filter__pb2.FilterGetMatchersRequest.SerializeToString,
            filter__pb2.FilterGetMatchersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LowerOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.FilterInterface/LowerOrder',
            filter__pb2.FilterLowerOrderRequest.SerializeToString,
            filter__pb2.FilterLowerOrderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OrderFirst(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.FilterInterface/OrderFirst',
            filter__pb2.FilterOrderFirstRequest.SerializeToString,
            filter__pb2.FilterOrderFirstResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OrderLast(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.FilterInterface/OrderLast',
            filter__pb2.FilterOrderLastRequest.SerializeToString,
            filter__pb2.FilterOrderLastResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RaiseOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.FilterInterface/RaiseOrder',
            filter__pb2.FilterRaiseOrderRequest.SerializeToString,
            filter__pb2.FilterRaiseOrderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunFilterOnGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.FilterInterface/RunFilterOnGroup',
            filter__pb2.FilterRunFilterOnGroupRequest.SerializeToString,
            filter__pb2.FilterRunFilterOnGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunFilterOnJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.FilterInterface/RunFilterOnJobs',
            filter__pb2.FilterRunFilterOnJobsRequest.SerializeToString,
            filter__pb2.FilterRunFilterOnJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetEnabled(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.FilterInterface/SetEnabled',
            filter__pb2.FilterSetEnabledRequest.SerializeToString,
            filter__pb2.FilterSetEnabledResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.FilterInterface/SetName',
            filter__pb2.FilterSetNameRequest.SerializeToString,
            filter__pb2.FilterSetNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.FilterInterface/SetOrder',
            filter__pb2.FilterSetOrderRequest.SerializeToString,
            filter__pb2.FilterSetOrderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetType(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.FilterInterface/SetType',
            filter__pb2.FilterSetTypeRequest.SerializeToString,
            filter__pb2.FilterSetTypeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class MatcherInterfaceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Commit = channel.unary_unary(
                '/filter.MatcherInterface/Commit',
                request_serializer=filter__pb2.MatcherCommitRequest.SerializeToString,
                response_deserializer=filter__pb2.MatcherCommitResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/filter.MatcherInterface/Delete',
                request_serializer=filter__pb2.MatcherDeleteRequest.SerializeToString,
                response_deserializer=filter__pb2.MatcherDeleteResponse.FromString,
                )
        self.GetParentFilter = channel.unary_unary(
                '/filter.MatcherInterface/GetParentFilter',
                request_serializer=filter__pb2.MatcherGetParentFilterRequest.SerializeToString,
                response_deserializer=filter__pb2.MatcherGetParentFilterResponse.FromString,
                )


class MatcherInterfaceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Commit(self, request, context):
        """Sets new properties for the [Matcher] on the server side using a [MatcherData] object.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Delete this matcher.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetParentFilter(self, request, context):
        """Returns the [Filter] this matcher is part of.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MatcherInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Commit': grpc.unary_unary_rpc_method_handler(
                    servicer.Commit,
                    request_deserializer=filter__pb2.MatcherCommitRequest.FromString,
                    response_serializer=filter__pb2.MatcherCommitResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=filter__pb2.MatcherDeleteRequest.FromString,
                    response_serializer=filter__pb2.MatcherDeleteResponse.SerializeToString,
            ),
            'GetParentFilter': grpc.unary_unary_rpc_method_handler(
                    servicer.GetParentFilter,
                    request_deserializer=filter__pb2.MatcherGetParentFilterRequest.FromString,
                    response_serializer=filter__pb2.MatcherGetParentFilterResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'filter.MatcherInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MatcherInterface(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Commit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.MatcherInterface/Commit',
            filter__pb2.MatcherCommitRequest.SerializeToString,
            filter__pb2.MatcherCommitResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.MatcherInterface/Delete',
            filter__pb2.MatcherDeleteRequest.SerializeToString,
            filter__pb2.MatcherDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetParentFilter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/filter.MatcherInterface/GetParentFilter',
            filter__pb2.MatcherGetParentFilterRequest.SerializeToString,
            filter__pb2.MatcherGetParentFilterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)